==> logicmonitor_sdk-python-3.0.172.tar.gz: python/docs/IntegrationMetadata.md <==
# IntegrationMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**target_last_published_id** | **str** | Specifies the target last published Id | [optional] 
**target_last_published_checksum** | **str** | The metadata checksum for the target last published LMModule content | [optional] 
**target_last_published_version** | **str** | Specifies the target last published version | [optional] 
**origin_checksum** | **str** | The metadata checksum for the LMModule content | [optional] 
**origin_author_namespace** | **str** | Specifies the origin Author companies namespace | [optional] 
**is_changed_from_origin** | **bool** | Specifies if the Applies To function is changed from origin or not | [optional] 
**audited_registry_id** | **str** | Specifies the audited registry Id | [optional] 
**target_lineage_id** | **str** | Specifies the target lineage Id | [optional] 
**logic_module_type** | **str** | DataSources | EventSources | PropertySources | ConfigSources | LogSources | TopologySources | Jobmonitors | AppliesTo Functions | SNMP SysOID Maps The type of LogicModule | [optional] 
**is_changed_from_target_last_published** | **bool** | Specifies if the Applies To function is changed from target last published or not | [optional] 
**origin_lineage_id** | **str** | The origin lineage Id of the LMmodule | [optional] 
**origin_author_company_uuid** | **str** | Specifies the origin Author companies unique Id | [optional] 
**local_module_id** | **int** | The LocalModule Id | [optional] 
**origin_registry_id** | **str** | The Registry ID of the Exchange Integration this module is based from | [optional] 
**origin_version** | **str** | Specifies the origin version | [optional] 
**audited_version** | **str** | Specifies the audited registry version | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> logicmonitor_sdk-python-3.0.200.tar.gz: python/docs/IntegrationMetadata.md <==
# IntegrationMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**target_last_published_id** | **str** | Specifies the target last published Id | [optional] 
**target_last_published_checksum** | **str** | The metadata checksum for the target last published LMModule content | [optional] 
**target_last_published_version** | **str** | Specifies the target last published version | [optional] 
**origin_checksum** | **str** | The metadata checksum for the LMModule content | [optional] 
**origin_author_namespace** | **str** | Specifies the origin Author companies namespace | [optional] 
**is_changed_from_origin** | **bool** | Specifies if the Applies To function is changed from origin or not | [optional] 
**audited_registry_id** | **str** | Specifies the audited registry Id | [optional] 
**target_lineage_id** | **str** | Specifies the target lineage Id | [optional] 
**logic_module_type** | **str** | The values can be DataSources | EventSources | PropertySources | ConfigSources | LogSources | TopologySources | Jobmonitors | AppliesTo Functions | SNMP SysOID Maps The type of LogicModule | [optional] 
**is_changed_from_target_last_published** | **bool** | Specifies if the Applies To function is changed from target last published or not | [optional] 
**origin_lineage_id** | **str** | The origin lineage Id of the LMmodule | [optional] 
**origin_author_company_uuid** | **str** | Specifies the origin Author companies unique Id | [optional] 
**local_module_id** | **int** | The LocalModule Id | [optional] 
**origin_registry_id** | **str** | The Registry ID of the Exchange Integration this module is based from | [optional] 
**origin_version** | **str** | Specifies the origin version | [optional] 
**audited_version** | **str** | Specifies the audited registry version | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
